@@ -1,12 +1,3 @@
-# -*- coding: utf-8 -*-
-"""
----------------------------------------------
-Created on 2025/4/28 15:25
-@author: ZhangYundi
-@email: yundi.xxii@outlook.com
----------------------------------------------
-"""
-
 from .exceptions import FailTaskError, WarnException
 from .pool import pool
 from .delay import delay
@@ -18,10 +9,11 @@ from .utils import (
     fn_info,
     module_from_str,
     fn_from_str,
+    locate,
 )
 from .lazy import lazy_import
 
-__version__ = "1.2.0"
+__version__ = "1.2.2"
 
 __all__ = [
     "FailTaskError",
