@@ -10,7 +10,7 @@ Description:
 """
 
 from typing import Any
-from hydra._internal.utils import _locate
+from .utils import locate
 
 class LazyImport:
     def __init__(self, full_name: str):
@@ -19,7 +19,7 @@ class LazyImport:
 
     def _load(self) -> Any:
         if self._obj is None:
-            self._obj = _locate(self._full_name)
+            self._obj = locate(self._full_name)
         return self._obj
 
     def __getattr__(self, attr: str) -> Any:
